<img src="https://user-images.githubusercontent.com/12603953/121100008-ef77f400-c7c6-11eb-9c10-d844baa55ad5.png" width="100" height="100" />

[![Build Status](https://circleci.com/gh/bcanfield/southpaw/tree/main.svg?style=shield)](https://circleci.com/gh/bcanfield/southpaw/?branch=main)



# Southpaw
## _MMA Daily Fantasy Sports Toolkit_



Southpaw is a suite of tools to provide simple interfaces to help maximize success in MMA DFS.

## Features

- Linear Lineup Generation

- Genetic Lineup Generation
- Scrapers
- ...more coming soon
